Этот текст может включать <a
href="http://www.python.org/doc/current/lib/typesseq-strings.html">форматные
строки (текст по-английски)</a>, которые разрешаются относительно списка
атрибутов.  Списко атрибутов перечислен ниже.

<ul>
    <li><b><code>real_name</code></b> -- "красивое" имя списка рассылки;
    обычно имя списка рассыкли с заглавной первой буквой.

    <li><b><code>list_name</code></b> -- имя, которое используется в адресах
    страниц. (<code>_internal_name</code> является эквивалентной, для
    совместимости с предыдущими версиями.)

    <li><b><code>host_name</code></b> -- полное название домена для списка рассылки.

    <li><b><code>web_page_url</code></b> -- базовый адрес для Mailman. Именно к этому
    адресу нужно добавлять, например, <em><code>listinfo/%(internal_name)s</code></em>
    чтобы получиться адрес информационной страницы для списка рассылки.

    <li><b><code>description</code></b> - краткое описание списка рассылки.
    <li><b><code>info</code></b> - полное описание списка рассылки.
    <li><b><code>cgiext</code></b> - расширение файлов CGI-сценариев.
</ul>
