This text can include 
<a href="http://www.python.org/doc/current/lib/typesseq-strings.html">Python
format strings</a> which are resolved against list attributes.  The
list of substitutions allowed are:

<ul>
    <li><b><code>real_name</code></b> - The `pretty' name of the list; usually
    the list name with capitalization.

    <li><b><code>list_name</code></b> - The name by which the list is
    identified in URLs, where case is significant.  (For backwards
    compability, <code>_internal_name</code> is equivalent.)

    <li><b><code>host_name</code></b> - The fully qualified domain name
    that the list server runs on.

    <li><b><code>web_page_url</code></b> - The base URL for Mailman.  This
    can be appended with,
    e.g. <em><code>listinfo/%(internal_name)s</code></em> to yield the
    listinfo page for the mailing list.

    <li><b><code>description</code></b> - The brief description of the
    mailing list.

    <li><b><code>info</code></b> - The full description of the mailing
    list.

    <li><b><code>cgiext</code></b> - The extension added to CGI scripts.
</ul>
