Į šį tekstą gali būti įtrauktos
<a href="http://www.python.org/doc/current/lib/typesseq-strings.html">Python
formato eilutės</a> kurios yra apdorojamos pagal požymius. 
Čia pateikiame pakeitimų sąrašą:

<ul>
    <li><b><code>real_name</code></b> - Sąrašo pavadinimas; dažniausiai
    iš didžiosios raidės.

    <li><b><code>list_name</code></b> - The name by which the list is
    identified in URLs, where case is significant.  (For backwards
    compability, <code>_internal_name</code> is equivalent.)

    <li><b><code>host_name</code></b> - The fully qualified domain name
    that the list server runs on.

    <li><b><code>web_page_url</code></b> - The base URL for Mailman.  This
    can be appended with,
    e.g. <em><code>listinfo/%(internal_name)s</code></em> to yield the
    listinfo page for the mailing list.

    <li><b><code>description</code></b> - Trumpas forumo aprašymas.

    <li><b><code>info</code></b> - Pilnas forumo aprašymas.

    <li><b><code>cgiext</code></b> - The extension added to CGI scripts.
</ul>
