Tento text může obsahovat <a
href="http://www.python.org/doc/current/lib/typesseq-strings.html">formátovací
příkazy Pythonu</a> které se nahrazují odpovídajícími hodnotami, při
generování stránky.  Nejdůležitější proměnné jsou:

<ul>
    <li><b><code>real_name</code></b> - `Hezké' jméno konference, 
    obvykle název, který má zachovánu velikost písmen tak jak je 
    zadán v konfiguraci.

    <li><b><code>list_name</code></b> - Jméno konference, tak jak
    se používá v URL, tedy tam kde záleží na velikosti písmen (všechna
    jsou převedena na malá).

    <li><b><code>host_name</code></b> - Celé DNS jméno serveru na
    kterém konference běží.
    
    <li><b><code>web_page_url</code></b> - Základní URL pro Mailman.
    Pokud je následováno např. tímto příkazem:
    <em><code>listinfo/%(internal_name)s</code></em>
    vede na stránku s informacemi o konferenci.

    <li><b><code>description</code></b> - Krátký, charakteristický
    popis konference, tak jak byl zadán při konfiguraci.

    <li><b><code>info</code></b> - Kompletní, dlouhý, popis konference.

    <li><b><code>cgiext</code></b> - přípona přidávaná k cgi scriptům.

</ul>
